==> corepdf-2.7.0.tar.gz: corepdf-v2.7.0/corepdf.h <==
/*
    *
    * This file is a part of CorePDF.
    * A PDF viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef COREPDF_H
#define COREPDF_H

#include <QtWidgets>

#include <cprime/infofunc.h>
#include <cprime/validityfunc.h>
#include <cprime/settingsmanage.h>
#include <cprime/pinmanage.h>

#include "qpdfnamespace.h"
#include "qpdfview.h"
#include "qpdfdocument.h"


namespace Ui {
	class corepdf;
}

class corepdf : public QWidget
{
    Q_OBJECT

public:
    explicit corepdf(QWidget *parent = nullptr);
    ~corepdf();

    void loadFile( const QString &path );

    QString workFilePath;

protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void on_tools_clicked();
    void on_shareIt_clicked();
    void on_pinIt_clicked();
    void on_openmetadataApp_clicked();
    void on_savePageAsPic_clicked();
    void on_spinBox_valueChanged( int );
    void on_zoomCB_currentIndexChanged( int );
    void on_rotate_clicked();
    void on_pageModeCombo_currentIndexChanged( int );
    void updateSpinBox( int );


    void openFileDialog();
private:
    Ui::corepdf       *ui;
    QPdfView          *PdfWidget;
    QPdfDocument      *PdfDoc;
    settingsManage    *sm = settingsManage::initialize( true );
    pinmanage          pin;
    bool               sideView, touch, continuousPage;
    int                sideViewSize, pageMode, zoomFactor;
    QSize              sideViewIconSize, toolBarIconSize;
    QPdf::Rotation     m_rotation = QPdf::Rotate0;

    void startsetup();
    void loadSettings();
};

#endif // COREPDF_H

==> corepdf-2.9.0.tar.gz: corepdf-v2.9.0/corepdf.h <==
/*
    *
    * This file is a part of CorePDF.
    * A PDF viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#pragma once

#include <QtWidgets>

#include <cprime/infofunc.h>
#include <cprime/settingsmanage.h>
#include <cprime/pinmanage.h>

#include "qpdfnamespace.h"
#include "qpdfview.h"
#include "qpdfdocument.h"

namespace Ui {
	class corepdf;
}

class corepdf : public QWidget
{
    Q_OBJECT

public:
    explicit corepdf(QWidget *parent = nullptr);
    ~corepdf();

    void loadFile( const QString &path );

    QString workFilePath;

protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void on_menu_clicked();
    void on_shareIt_clicked();
    void on_pinIt_clicked();
    void on_openmetadataApp_clicked();
    void on_savePageAsPic_clicked();
    void on_spinBox_valueChanged( int );
    void on_zoomCB_currentIndexChanged( int );
    void on_rotate_clicked();
    void on_pageModeCombo_currentIndexChanged( int );
    void updateSpinBox( int );
    void openFileDialog();

private:
    Ui::corepdf       *ui;
    QPdfView          *PdfWidget;
    QPdfDocument      *PdfDoc;
    settingsManage    *sm = settingsManage::initialize( true );
    pinmanage          pin;
    bool               sideView, touch, continuousPage, experimental;
    int                sideViewSize, pageMode, zoomFactor;
    QSize              sideViewIconSize, toolBarIconSize;
    QPdf::Rotation     m_rotation = QPdf::Rotate0;

    void startsetup();
    void loadSettings();
};

class PageSaver: public QThread {
	Q_OBJECT

	public:
		PageSaver( QString name, int page, int zoomVal, QString saveName );

	private:
		QString pdfName;
		int pageNo;
		int zoom;
		QString imgName;

	protected:
		void run() override;
};
